from imagesc.imagesc import (
    seaborn,
    cluster,
    fast,
    clean,
    plot)

from imagesc.savefig import savefig

__author__ = 'Erdogan Tasksen'
__email__ = 'erdogant@gmail.com'

# module level doc-string
__doc__ = """
imagesc - imagesc is an Python package to create heatmaps.
=====================================================================

**imagesc** 
See README.md file for more information.

"""
